=======
History
=======

0.1.0 (2024-09-18)
------------------

* First release on PyPI.


0.2.0
------------------

* NABuilder, DSNABuilder, NucleicAcid and DoubleStrandNucleicAcid classes.

0.2.1
------------------

* Building and deploying docs on readthedocs.
